@@ -1,4 +1,4 @@
-from typing import Type, Dict, Any, Optional
+from typing import Type, Dict, Any, Optional, cast
 
 import pandas as pd
 
@@ -7,10 +7,11 @@ from declafe.feature_gen import FeatureGen
 __all__ = ["BiComposeFeature"]
 
 from .BinaryFeature import BinaryFeature
+from ..unary import IdFeature
+from ... import ConstFeature
 
 
 class BiComposeFeature(FeatureGen):
-  """check if left is greater than right"""
 
   def __init__(self,
                left: FeatureGen,
@@ -32,9 +33,23 @@ class BiComposeFeature(FeatureGen):
     return self.to_instance().feature_name
 
   def to_instance(self):
-    return self.to(left=self.left.feature_name,
-                   right=self.right.feature_name,
-                   **self.toKwargs)
+    gen = self.to(left=self.left.feature_name,
+                  right=self.right.feature_name,
+                  **self.toKwargs)
+    left_name = self.__wrap_name(self.left)
+    right_name = self.__wrap_name(self.right)
+
+    return cast(
+        BinaryFeature,
+        gen.as_name_of(
+            gen.feature_name.replace(self.left.feature_name,
+                                     left_name).replace(self.right.feature_name,
+                                                        right_name)))
+
+  def __wrap_name(self, f: FeatureGen):
+    return f"({f.feature_name})" \
+      if not isinstance(f, (ConstFeature, IdFeature)) \
+      else f.feature_name
 
   @staticmethod
   def make(left: FeatureGen,
