@@ -2,15 +2,15 @@ from abc import ABC, abstractmethod
 
 import pandas as pd
 
-from ..FeatureGen import FeatureGen
+from ..FeatureGen import FeatureGen, ColLike
 
 
 class BinaryFeature(FeatureGen, ABC):
 
-  def __init__(self, left: str, right: str):
+  def __init__(self, left: ColLike, right: ColLike):
     super().__init__()
-    self.left = left
-    self.right = right
+    self.left = self.to_col(left)
+    self.right = self.to_col(right)
 
   @abstractmethod
   def bigen(self, left: pd.Series, right: pd.Series) -> pd.Series:
