@@ -2,11 +2,11 @@ from .BiComposeFeature import BiComposeFeature
 from .ops import *
 from .ops.AddFeature import *
 from .ops.GEFeature import *
-from .ops.IsGreaterFeature import *
-from .ops.IsLessFeature import *
+from .ops.GTFeature import *
+from .ops.LTFeature import *
 from .ops.LEFeature import *
 from .ops.ModFeature import *
-from .ops.ProductFeature import *
+from .ops.MulFeature import *
 from .ops.SubFeature import *
 from .talib.AROONFeature import *
 from .talib.AROONOSCFeature import *
