@@ -1,10 +1,10 @@
 from .AddFeature import *
 from .DivideFeature import *
-from .EqualFeature import *
+from .EqFeature import *
 from .GEFeature import *
-from .IsGreaterFeature import *
-from .IsLessFeature import *
+from .GTFeature import *
+from .LTFeature import *
 from .LEFeature import *
 from .ModFeature import *
-from .ProductFeature import *
+from .MulFeature import *
 from .SubFeature import *
