@@ -15,9 +15,6 @@ class LagFeature(UnaryColumnFeature):
     super().__init__(column_name)
     self.periods = periods
 
-    if self.periods <= 0:
-      raise ValueError("periodsは正の整数である必要があります")
-
   @property
   def name(self) -> str:
     return f"lag_{self.periods}"
