@@ -4,7 +4,9 @@ from .UnaryColumnFeature import UnaryColumnFeature
 
 __all__ = ["NotFeature"]
 
+
 class NotFeature(UnaryColumnFeature):
+
   @property
   def name(self) -> str:
     return f"~"
@@ -13,4 +15,4 @@ class NotFeature(UnaryColumnFeature):
     return "~" + self.column_name
 
   def gen_unary(self, ser: pd.Series) -> pd.Series:
-    return ~ser
+    return (~ser).astype(bool)
