@@ -8,13 +8,18 @@ __all__ = ["BBandsUpperFeature", "BBandsLowerFeature"]
 
 class BBandsUpperFeature(UnaryColumnFeature):
 
-  def __init__(self, periods: int, column_name: str, nbdevup: float = 2):
+  def __init__(self,
+               periods: int,
+               column_name: str,
+               nbdevup: float,
+               matype: int = 0):
     super().__init__(column_name)
     self.periods = periods
     self.nbdevup = nbdevup
+    self.matype = matype
 
   def gen_unary(self, ser: pd.Series) -> pd.Series:
-    return talib.BBANDS(ser, self.periods, self.nbdevup, 2, 0)[0]
+    return talib.BBANDS(ser, self.periods, self.nbdevup, 2, self.matype)[0]
 
   @property
   def name(self) -> str:
@@ -23,13 +28,18 @@ class BBandsUpperFeature(UnaryColumnFeature):
 
 class BBandsLowerFeature(UnaryColumnFeature):
 
-  def __init__(self, periods: int, column_name: str, nbdevdn: float = 2):
+  def __init__(self,
+               periods: int,
+               column_name: str,
+               nbdevdn: float,
+               matype: int = 0):
     super().__init__(column_name)
     self.periods = periods
     self.nbdevdn = nbdevdn
+    self.matype = matype
 
   def gen_unary(self, ser: pd.Series) -> pd.Series:
-    return talib.BBANDS(ser, self.periods, 2, self.nbdevdn, 0)[2]
+    return talib.BBANDS(ser, self.periods, 2, self.nbdevdn, self.matype)[2]
 
   @property
   def name(self) -> str:
