@@ -1,5 +1,3 @@
-from dataclasses import dataclass
-
 import pandas as pd
 
 from ..UnaryColumnFeature import UnaryColumnFeature
@@ -7,7 +5,6 @@ from ..UnaryColumnFeature import UnaryColumnFeature
 __all__ = ["DayOfWeekFeature"]
 
 
-@dataclass
 class DayOfWeekFeature(UnaryColumnFeature):
 
   def gen_unary(self, ser: pd.Series) -> pd.Series:
